pub struct GpuVertexRanges {
pub mesh_range: UVec2,
pub skeleton_range: UVec2,
}Expand description
The skeleton and mes vertex ranges, in a format that’s suitable to be sent to the GPU.
Note that there’s no need for this struct to be #[repr(C)]
because this is not the actual data that gets uploaded for GPU skinning.
Fields
mesh_range: UVec2The range of the vertex buffer that holds the original mesh.
skeleton_range: UVec2The range of the vertex buffer that holds the duplicate mesh data, owned by the Skeleton