pub enum OutputFrame {
Surface {
surface: Arc<Surface>,
},
SurfaceAcquired {
view: TextureView,
surface_tex: SurfaceTexture,
},
View(Arc<TextureView>),
}Expand description
Anything that resembles a surface to render to.
Variants
Implementations
Sourceimpl OutputFrame
impl OutputFrame
Sourcepub fn acquire(&mut self) -> Result<(), SurfaceError>
pub fn acquire(&mut self) -> Result<(), SurfaceError>
If needed, acquire the surface. If the frame is Surface, after this call it will be SurfaceAcquired.
Sourcepub fn as_view(&self) -> Option<&TextureView>
pub fn as_view(&self) -> Option<&TextureView>
Turn the given surface into a texture view, if it has one.